@@ -85,7 +85,6 @@ defmodule Ejabberd.MixProject do
     result = [{:d, :ELIXIR_ENABLED}] ++
              cond_options() ++
              Enum.map(includes, fn (path) -> {:i, path} end) ++
-             if_version_above(~c"20", [{:d, :DEPRECATED_GET_STACKTRACE}]) ++
              if_version_above(~c"20", [{:d, :HAVE_URI_STRING}]) ++
              if_version_above(~c"20", [{:d, :HAVE_ERL_ERROR}]) ++
              if_version_below(~c"21", [{:d, :USE_OLD_HTTP_URI}]) ++
@@ -99,6 +98,7 @@ defmodule Ejabberd.MixProject do
              if_version_below(~c"25", [{:d, :OTP_BELOW_25}]) ++
              if_version_below(~c"26", [{:d, :OTP_BELOW_26}]) ++
              if_version_below(~c"27", [{:d, :OTP_BELOW_27}]) ++
+             if_version_below(~c"27", [{:feature, :maybe_expr, :enable}]) ++
              if_version_below(~c"28", [{:d, :OTP_BELOW_28}])
     defines = for {:d, value} <- result, do: {:d, value}
     result ++ [{:d, :ALL_DEFS, defines}]
@@ -110,7 +110,7 @@ defmodule Ejabberd.MixProject do
                             {config(:debug), :debug_info},
                             {not config(:debug), {:debug_info, false}},
                             {config(:roster_gateway_workaround), {:d, :ROSTER_GATEWAY_WORKAROUND}},
-                            {config(:new_sql_schema), {:d, :NEW_SQL_SCHEMA}}
+                            {config(:multihost_sql_schema), {:d, :MULTIHOST_SQL_SCHEMA}}
                            ], do:
     option
   end
@@ -125,13 +125,13 @@ defmodule Ejabberd.MixProject do
      {:fast_yaml, "~> 1.0"},
      {:idna, "~> 6.0"},
      {:mqtree, "~> 1.0"},
-     {:p1_acme, "~> 1.0.27"},
+     {:p1_acme, ">= 1.0.28"},
      {:p1_oauth2, "~> 0.6"},
      {:p1_utils, "~> 1.0"},
      {:pkix, "~> 1.0"},
      {:stringprep, ">= 1.0.26"},
-     {:xmpp, ">= 1.11.0"},
-     {:yconf, ">= 1.0.18"}]
+     {:xmpp, ">= 1.11.2"},
+     {:yconf, ">= 1.0.22"}]
     ++ cond_deps()
   end
 
