@@ -151,13 +151,7 @@ get_users(Server, []) ->
     Users = mnesia:dirty_select(passwd,
 			[{#passwd{us = '$1', _ = '_'},
 			  [{'==', {element, 2, '$1'}, Server}], ['$1']}]),
-    {_, Res} = lists:foldl(
-	fun({U, S, _}, {{U2, S2}, _} = Acc) when U == U2 andalso S == S2 ->
-	    Acc;
-	   ({U, S, _}, {_, Res}) ->
-	       {{U, S}, [{U, S} | Res]}
-	end, {{none, none}, []}, Users),
-    Res;
+    misc:lists_uniq([{U, S} || {U, S, _} <- Users]);
 get_users(Server, [{from, Start}, {to, End}])
   when is_integer(Start) and is_integer(End) ->
     get_users(Server, [{limit, End - Start + 1}, {offset, Start}]);
