@@ -52,7 +52,7 @@
 	     {get_lang, 1}]).
 
 -include("logger.hrl").
--include("ejabberd_stacktrace.hrl").
+
 
 -type option() :: atom() | {atom(), global | binary()}.
 -type error_reason() :: {merge_conflict, atom(), binary()} |
@@ -169,14 +169,14 @@ get_option({O, Host} = Opt) ->
 	      T -> T
 	  end,
     try ets:lookup_element(Tab, Opt, 2)
-    catch ?EX_RULE(error, badarg, St) when Host /= global ->
-	    StackTrace = ?EX_STACK(St),
-	    Val = get_option({O, global}),
-	    ?DEBUG("Option '~ts' is not defined for virtual host '~ts'. "
-		   "This is a bug, please report it with the following "
-		   "stacktrace included:~n** ~ts",
-		   [O, Host, misc:format_exception(2, error, badarg, StackTrace)]),
-	    Val
+    catch
+        error:badarg:StackTrace when Host /= global ->
+            Val = get_option({O, global}),
+            ?DEBUG("Option '~ts' is not defined for virtual host '~ts'. "
+                   "This is a bug, please report it with the following "
+                   "stacktrace included:~n** ~ts",
+                   [O, Host, misc:format_exception(2, error, badarg, StackTrace)]),
+            Val
     end.
 
 -spec set_option(option(), term()) -> ok.
@@ -264,30 +264,31 @@ version() ->
 
 -spec default_db(binary() | global, module()) -> atom().
 default_db(Host, Module) ->
-    default_db(default_db, Host, Module, mnesia).
+    default_db(default_db, db_type, Host, Module, mnesia).
 
 -spec default_db(binary() | global, module(), atom()) -> atom().
 default_db(Host, Module, Default) ->
-    default_db(default_db, Host, Module, Default).
+    default_db(default_db, db_type, Host, Module, Default).
 
 -spec default_ram_db(binary() | global, module()) -> atom().
 default_ram_db(Host, Module) ->
-    default_db(default_ram_db, Host, Module, mnesia).
+    default_db(default_ram_db, ram_db_type, Host, Module, mnesia).
 
 -spec default_ram_db(binary() | global, module(), atom()) -> atom().
 default_ram_db(Host, Module, Default) ->
-    default_db(default_ram_db, Host, Module, Default).
+    default_db(default_ram_db, ram_db_type, Host, Module, Default).
 
--spec default_db(default_db | default_ram_db, binary() | global, module(), atom()) -> atom().
-default_db(Opt, Host, Mod, Default) ->
+-spec default_db(default_db | default_ram_db, db_type | ram_db_type, binary() | global, module(), atom()) -> atom().
+default_db(Opt, ModOpt, Host, Mod, Default) ->
     Type = get_option({Opt, Host}),
     DBMod = list_to_atom(atom_to_list(Mod) ++ "_" ++ atom_to_list(Type)),
     case code:ensure_loaded(DBMod) of
 	{module, _} -> Type;
 	{error, _} ->
 	    ?WARNING_MSG("Module ~ts doesn't support database '~ts' "
-			 "defined in option '~ts', using "
-			 "'~ts' as fallback", [Mod, Type, Opt, Default]),
+			 "defined in toplevel option '~ts': will use the value "
+                         "set in ~ts option '~ts', or '~ts' as fallback",
+                         [Mod, Type, Opt, Mod, ModOpt, Default]),
 	    Default
     end.
 
@@ -507,7 +508,7 @@ get_predefined_keywords(Host) ->
             global ->
                 [];
             _ ->
-                [{<<"HOST">>, Host}]
+                [{<<"HOST">>, Host}, {<<"HOST_URL_ENCODE">>, misc:url_encode(Host)}]
         end,
     Home = misc:get_home(),
     ConfigDirPath =
@@ -631,22 +632,7 @@ callback_modules(external) ->
 	      end
       end, beams(external));
 callback_modules(all) ->
-    lists_uniq(callback_modules(local) ++ callback_modules(external)).
-
--ifdef(OTP_BELOW_25).
-lists_uniq(List) ->
-    {Res, _} = lists:foldr(
-	fun(El, {Result, Existing} = Acc) ->
-	    case maps:is_key(El, Existing) of
-		true -> Acc;
-		_ -> {[El | Result], Existing#{El => true}}
-	    end
-	end, {[], #{}}, List),
-    Res.
--else.
-lists_uniq(List) ->
-    lists:uniq(List).
--endif.
+    misc:lists_uniq(callback_modules(local) ++ callback_modules(external)).
 
 -spec validators(module(), [atom()], [any()]) -> econf:validators().
 validators(Mod, Disallowed, DK) ->
@@ -816,8 +802,9 @@ load_file(File) ->
 	    Err ->
 		abort(Err)
 	end
-    catch ?EX_RULE(Class, Reason, St) ->
-	    {error, {exception, Class, Reason, ?EX_STACK(St)}}
+    catch
+        Class:Reason:Stack ->
+            {error, {exception, Class, Reason, Stack}}
     end.
 
 -spec commit() -> ok.
