@@ -39,7 +39,7 @@
 -include("ejabberd_commands.hrl").
 -include("ejabberd_http.hrl").
 -include("logger.hrl").
--include("ejabberd_stacktrace.hrl").
+
 
 -define(DEFAULT_VERSION, 1000000).
 
@@ -331,11 +331,10 @@ try_call_command(Args, Auth, AccessCommands, Version) ->
 	     ?STATUS_ERROR};
 	throw:Error ->
 	    {io_lib:format("~p", [Error]), ?STATUS_ERROR};
-	?EX_RULE(A, Why, Stack) ->
-	    StackTrace = ?EX_STACK(Stack),
-	    {io_lib:format("Unhandled exception occurred executing the command:~n** ~ts",
-			   [misc:format_exception(2, A, Why, StackTrace)]),
-	     ?STATUS_ERROR}
+        A:Why:StackTrace ->
+            {io_lib:format("Unhandled exception occurred executing the command:~n** ~ts",
+                           [misc:format_exception(2, A, Why, StackTrace)]),
+             ?STATUS_ERROR}
     end.
 
 -spec call_command(Args::[string()],
@@ -390,6 +389,8 @@ format_arg(Arg, integer) ->
     format_arg2(Arg, "~d");
 format_arg(Arg, binary) ->
     unicode:characters_to_binary(Arg, utf8);
+format_arg(Arg, binary_or_list) ->
+    [unicode:characters_to_binary(Arg, utf8)];
 format_arg("", string) ->
     "";
 format_arg(Arg, string) ->
@@ -1000,12 +1001,12 @@ format_usage_ctype1({Name, Type, Description}, Indentation, ShCode) ->
 
 format_usage_ctype(Type, _Indentation)
   when (Type==atom) or (Type==integer) or (Type==string) or (Type==binary)
-       or (Type==rescode) or (Type==restuple) ->
+       or (Type==rescode) or (Type==restuple) or (Type==binary_or_list) ->
     io_lib:format("~p", [Type]);
 
 format_usage_ctype({Name, Type}, _Indentation)
   when (Type==atom) or (Type==integer) or (Type==string) or (Type==binary)
-       or (Type==rescode) or (Type==restuple)
+       or (Type==rescode) or (Type==restuple) or (Type==binary_or_list)
        or (Type==any) ->
     io_lib:format("~p::~p", [Name, Type]);
 
@@ -1148,6 +1149,17 @@ get_commands_spec() ->
 			desc = "Get list of commands, or help of a command (only ejabberdctl)",
 			longdesc = "This command is exclusive for the ejabberdctl command-line script, "
 			"don't attempt to execute it using any other API frontend."},
+     #ejabberd_commands{name = mnesia_change, tags = [ejabberdctl, mnesia],
+			desc = "Change the erlang node name in the mnesia database (only ejabberdctl)",
+			longdesc = "This command internally calls the _`mnesia_change_nodename`_ API. "
+			"This is a special command that starts and stops ejabberd several times: "
+			"do not attempt to run this command when ejabberd is running. "
+			"This command is exclusive for the ejabberdctl command-line script, "
+			"don't attempt to execute it using any other API frontend.",
+			note = "added in 25.08",
+			args = [{old_node_name, string}],
+			args_desc = ["Old erlang node name"],
+			args_example = ["ejabberd@oldmachine"]},
      #ejabberd_commands{name = mnesia_info_ctl, tags = [ejabberdctl, mnesia],
 			desc = "Show information of Mnesia system (only ejabberdctl)",
 			note = "renamed in 24.02",
@@ -1158,9 +1170,9 @@ get_commands_spec() ->
 			longdesc = "This command is exclusive for the ejabberdctl command-line script, "
 			"don't attempt to execute it using any other API frontend.",
 			note = "added in 24.02",
-			args = [{db_type, string}, {db_version, string}, {new_schema, string}],
+			args = [{db_type, string}, {db_version, string}, {multihost_schema, string}],
                         args_desc = ["Database type: pgsql | mysql | sqlite",
                                      "Your database version: 16.1, 8.2.0...",
-                                     "Use new schema: 0, false, 1 or true"],
+                                     "Use multihost schema: 0, false, 1 or true"],
                         args_example = ["pgsql", "16.1", "true"]}
     ].
