@@ -39,7 +39,7 @@
 -include("logger.hrl").
 -include_lib("xmpp/include/xmpp.hrl").
 -include("ejabberd_http.hrl").
--include("ejabberd_stacktrace.hrl").
+
 -include_lib("kernel/include/file.hrl").
 
 -record(state, {sockmod,
@@ -372,11 +372,11 @@ process(Handlers, Request) ->
                         try
                             HandlerModule:process(LocalPath, Request)
                         catch
-                            ?EX_RULE(Class, Reason, Stack) ->
+                            Class:Reason:Stack ->
                                 ?ERROR_MSG(
-                                   "HTTP handler crashed: ~s",
-                                   [misc:format_exception(2, Class, Reason, ?EX_STACK(Stack))]),
-                                erlang:raise(Class, Reason, ?EX_STACK(Stack))
+                                  "HTTP handler crashed: ~s",
+                                  [misc:format_exception(2, Class, Reason, Stack)]),
+                                erlang:raise(Class, Reason, Stack)
                         end
 		end,
             ejabberd_hooks:run(http_request_debug, [{LocalPath, Request}]),
@@ -718,7 +718,7 @@ file_format_error(Reason) ->
 url_decode_q_split_normalize(Path) ->
     {NPath, Query} = url_decode_q_split(Path),
     LPath = normalize_path([NPE
-		    || NPE <- str:tokens(path_decode(NPath), <<"/">>)]),
+		    || NPE <- str:tokens(misc:uri_decode(NPath), <<"/">>)]),
     {LPath, Query}.
 
 % Code below is taken (with some modifications) from the yaws webserver, which
@@ -746,19 +746,6 @@ url_decode_q_split(<<H, T/binary>>, Acc) when H /= 0 ->
 url_decode_q_split(<<>>, Ack) ->
     {path_norm_reverse(Ack), <<>>}.
 
-%% @doc Decode a part of the URL and return string()
-path_decode(Path) -> path_decode(Path, <<>>).
-
-path_decode(<<$%, Hi, Lo, Tail/binary>>, Acc) ->
-    Hex = list_to_integer([Hi, Lo], 16),
-    if Hex == 0 -> exit(badurl);
-       true -> ok
-    end,
-    path_decode(Tail, <<Acc/binary, Hex>>);
-path_decode(<<H, T/binary>>, Acc) when H /= 0 ->
-    path_decode(T, <<Acc/binary, H>>);
-path_decode(<<>>, Acc) -> Acc.
-
 path_norm_reverse(<<"/", T/binary>>) -> start_dir(0, <<"/">>, T);
 path_norm_reverse(T) -> start_dir(0, <<"">>, T).
 
