@@ -113,12 +113,12 @@ init({Port, _, udp} = EndPoint, Module, Opts, SockOpts) ->
 				 {Port, SockOpts}
 			 end,
     ExtraOpts2 = lists:keydelete(send_timeout, 1, ExtraOpts),
-    case gen_udp:open(Port2, [binary,
+    case {gen_udp:open(Port2, [binary,
 			     {active, false},
 			     {reuseaddr, true} |
-			     ExtraOpts2]) of
-	{ok, Socket} ->
-            set_definitive_udsocket(Port, Opts),
+			     ExtraOpts2]),
+          set_definitive_udsocket(Port, Opts)} of
+	{{ok, Socket}, ok} ->
             misc:set_proc_label({?MODULE, udp, Port}),
 	    case inet:sockname(Socket) of
 		{ok, {Addr, Port1}} ->
@@ -139,18 +139,18 @@ init({Port, _, udp} = EndPoint, Module, Opts, SockOpts) ->
 			{error, _} ->
 			    ok
 		    end;
-		{error, Reason} = Err ->
-		    report_socket_error(Reason, EndPoint, Module),
-		    proc_lib:init_ack(Err)
+		{error, Reason} ->
+		    return_socket_error(Reason, EndPoint, Module)
 	    end;
-	{error, Reason} = Err ->
-	    report_socket_error(Reason, EndPoint, Module),
-	    proc_lib:init_ack(Err)
+	{{error, Reason}, _} ->
+	    return_socket_error(Reason, EndPoint, Module);
+	{_, {error, Reason} } ->
+	    return_socket_error(Reason, EndPoint, Module)
     end;
 init({Port, _, tcp} = EndPoint, Module, Opts, SockOpts) ->
-    case listen_tcp(Port, SockOpts) of
-	{ok, ListenSocket} ->
-            set_definitive_udsocket(Port, Opts),
+    case {listen_tcp(Port, SockOpts),
+          set_definitive_udsocket(Port, Opts)} of
+	{{ok, ListenSocket}, ok} ->
 	    case inet:sockname(ListenSocket) of
 		{ok, {Addr, Port1}} ->
 		    proc_lib:init_ack({ok, self()}),
@@ -174,13 +174,13 @@ init({Port, _, tcp} = EndPoint, Module, Opts, SockOpts) ->
 			{error, _} ->
 			    ok
 		    end;
-		{error, Reason} = Err ->
-		    report_socket_error(Reason, EndPoint, Module),
-		    proc_lib:init_ack(Err)
+		{error, Reason} ->
+		    return_socket_error(Reason, EndPoint, Module)
 	    end;
-	{error, Reason} = Err ->
-	    report_socket_error(Reason, EndPoint, Module),
-	    proc_lib:init_ack(Err)
+	{{error, Reason}, _} ->
+	    return_socket_error(Reason, EndPoint, Module);
+	{_, {error, Reason}} ->
+	    return_socket_error(Reason, EndPoint, Module)
     end.
 
 -spec listen_tcp(inet:port_number(), [gen_tcp:option()]) ->
@@ -216,23 +216,39 @@ listen_tcp(Port, SockOpts) ->
 
 setup_provisional_udsocket_dir(DefinitivePath) ->
     ProvisionalPath = get_provisional_udsocket_path(DefinitivePath),
-    ?DEBUG("Creating a Unix Domain Socket provisional file at ~ts for the definitive path ~s",
+    ?INFO_MSG("Creating a Unix Domain Socket provisional file at ~ts for the definitive path ~s",
               [ProvisionalPath, DefinitivePath]),
-    ProvisionalPath.
+    ProvisionalPathAbsolute = relative_socket_to_mnesia(ProvisionalPath),
+    create_base_dir(ProvisionalPathAbsolute),
+    ProvisionalPathAbsolute.
 
 get_provisional_udsocket_path(Path) ->
-    PathBase64 = misc:term_to_base64(Path),
+    ReproducibleSecret = binary:part(crypto:hash(sha, misc:atom_to_binary(erlang:get_cookie())), 1, 8),
+    PathBase64 = misc:term_to_base64({ReproducibleSecret, Path}),
     PathBuild = filename:join(misc:get_home(), PathBase64),
-    %% Shorthen the path, a long path produces a crash when opening the socket.
-    binary:part(PathBuild, {0, erlang:min(107, byte_size(PathBuild))}).
+    DestPath = filename:join(filename:dirname(Path), PathBase64),
+    case {byte_size(DestPath) > 107, byte_size(PathBuild) > 107} of
+        {false, _} ->
+            DestPath;
+        {true, false} ->
+            ?INFO_MSG("The provisional Unix Domain Socket path ~ts is longer than 107, let's use home directory instead which is ~p", [DestPath, byte_size(PathBuild)]),
+            PathBuild;
+        {true, true} ->
+            ?ERROR_MSG("The Unix Domain Socket path ~ts is too long, "
+                       "and I cannot create the provisional file safely. "
+                       "Please configure a shorter path and try again.", [Path]),
+            throw({error_socket_path_too_long, Path})
+    end.
 
 get_definitive_udsocket_path(<<"unix", _>> = Unix) ->
     Unix;
 get_definitive_udsocket_path(ProvisionalPath) ->
     PathBase64 = filename:basename(ProvisionalPath),
-    {term, Path} = misc:base64_to_term(PathBase64),
+    {term, {_, Path}} = misc:base64_to_term(PathBase64),
     relative_socket_to_mnesia(Path).
 
+-spec set_definitive_udsocket(integer() | binary(), opts()) -> ok | {error, file:posix() | badarg}.
+
 set_definitive_udsocket(<<"unix:", Path/binary>>, Opts) ->
     Prov = get_provisional_udsocket_path(Path),
     Usd = maps:get(unix_socket, Opts),
@@ -263,16 +279,19 @@ set_definitive_udsocket(<<"unix:", Path/binary>>, Opts) ->
             end
     end,
     FinalPath = relative_socket_to_mnesia(Path),
-    FinalPathDir = filename:dirname(FinalPath),
-    case file:make_dir(FinalPathDir) of
+    create_base_dir(FinalPath),
+    file:rename(Prov, FinalPath);
+set_definitive_udsocket(Port, _Opts) when is_integer(Port) ->
+    ok.
+
+create_base_dir(Path) ->
+    Dirname = filename:dirname(Path),
+    case file:make_dir(Dirname) of
         ok ->
-            file:change_mode(FinalPathDir, 8#00700);
+            file:change_mode(Dirname, 8#00700);
         _ ->
             ok
-    end,
-    file:rename(Prov, FinalPath);
-set_definitive_udsocket(_Port, _Opts) ->
-    ok.
+    end.
 
 relative_socket_to_mnesia(Path1) ->
     case filename:pathtype(Path1) of
@@ -304,6 +323,8 @@ split_opts(Transport, Opts) ->
 		      {ModOpts, [{Opt, Val} | SockOpts]};
 		  {backlog, _} ->
 		      {ModOpts, SockOpts};
+          {send_timeout, _} ->
+		      {ModOpts, [{Opt, Val} | SockOpts]};
 		  _ ->
 		      {ModOpts#{Opt => Val}, SockOpts}
 	      end
@@ -584,10 +605,20 @@ config_reloaded() ->
 	      end
       end, New).
 
--spec report_socket_error(inet:posix(), endpoint(), module()) -> ok.
-report_socket_error(Reason, EndPoint, Module) ->
+-spec return_socket_error(inet:posix(), endpoint(), module()) -> no_return().
+return_socket_error(Reason, EndPoint, Module) ->
     ?ERROR_MSG("Failed to open socket at ~ts for ~ts: ~ts",
-	       [format_endpoint(EndPoint), Module, format_error(Reason)]).
+               [format_endpoint(EndPoint), Module, format_error(Reason)]),
+    return_init_error(Reason).
+
+-ifdef(OTP_BELOW_26).
+return_init_error(Reason) ->
+    proc_lib:init_ack({error, Reason}).
+-else.
+-spec return_init_error(inet:posix()) -> no_return().
+return_init_error(Reason) ->
+    proc_lib:init_fail({error, Reason}, {exit, normal}).
+-endif.
 
 -spec format_error(inet:posix() | atom()) -> string().
 format_error(Reason) ->
