@@ -109,14 +109,20 @@ doc() ->
         desc =>
             ?T("_`database.md#default-database|Default database`_ "
                "to store persistent data in ejabberd. "
-               "Modules and other components (e.g. authentication) "
-               "may have its own value. The default value is 'mnesia'.")}},
+               "Some components can be configured with specific toplevel options "
+               "like _`oauth_db_type`_. "
+               "Many modules can be configured with specific module options, "
+               "usually named `db_type`. "
+               "The default value is 'mnesia'.")}},
      {default_ram_db,
       #{value => "mnesia | redis | sql",
         desc =>
             ?T("Default volatile (in-memory) storage for ejabberd. "
-               "Modules and other components (e.g. session management) "
-               "may have its own value. The default value is 'mnesia'.")}},
+               "Some components can be configured with specific toplevel options "
+               "like _`router_db_type`_ and _`sm_db_type`_. "
+               "Some modules can be configured with specific module options, "
+               "usually named `ram_db_type`. "
+               "The default value is 'mnesia'.")}},
      {queue_type,
       #{value => "ram | file",
         desc =>
@@ -393,12 +399,12 @@ doc() ->
                "depends on the _`auth_scram_hash`_ option."), "",
             ?T("The default value is 'plain'."), ""]}},
 
-     {auth_password_types_hidden_in_scram1,
+     {auth_password_types_hidden_in_sasl1,
       #{value => "[plain | scram_sha1 | scram_sha256 | scram_sha512]",
         note => "added in 25.07",
         desc =>
-        ?T("List of password types that should not be offered in SCRAM1 authenticatication. "
-           "Because SCRAM1, unlike SCRAM2, can't have list of available mechanisms tailored to "
+        ?T("List of password types that should not be offered in SASL1 authenticatication. "
+           "Because SASL1, unlike SASL2, can't have list of available mechanisms tailored to "
            "individual user, it's possible that offered mechanisms will not be compatible "
            "with stored password, especially if new password type was added recently. "
            "This option allows disabling offering some mechanisms in SASL1, to a time until new "
@@ -986,23 +992,30 @@ doc() ->
                "bugs. Usually leaving default value of this is option is best, "
                "tweak it only if you know what you are doing. "
                "The default value is '1 minute'.")}},
-     {new_sql_schema,
+     {sql_schema_multihost,
       #{value => "true | false",
+        note => "renamed in 25.10",
         desc =>
             {?T("Whether to use the "
-                "_`database.md#default-and-new-schemas|new SQL schema`_. "
+                "_`database.md#default-and-new-schemas|multihost SQL schema`_. "
                 "All schemas are located "
                 "at <https://github.com/processone/ejabberd/tree/~s/sql>. "
-                "There are two schemas available. The default legacy schema "
+                "There are two schemas available. The legacy 'singlehost' schema "
                 "stores one XMPP domain into one ejabberd database. "
-                "The 'new' schema can handle several XMPP domains in a "
-                "single ejabberd database. Using this 'new' schema is best when "
+                "The 'multihost' schema can handle several XMPP domains in a "
+                "single ejabberd database. The 'multihost' schema is preferable when "
                 "serving several XMPP domains and/or changing domains from "
                 "time to time. This avoid need to manage several databases and "
                 "handle complex configuration changes. The default depends on "
-                "configuration flag '--enable-new-sql-schema' which is set "
+                "configuration flag '--enable-sql-schema-multihost' which is set "
                 "at compile time."),
              [binary:part(ejabberd_config:version(), {0,5})]}}},
+     {new_sql_schema,
+      #{value => "true | false",
+        note => "obsoleted in 25.10",
+        desc =>
+            ?T("This option was renamed to _`sql_schema_multihost`_ in ejabberd 25.10. "
+                "Please update your configuration to use the new option name")}},
      {update_sql_schema,
       #{value => "true | false",
         note => "updated in 24.06",
