@@ -48,7 +48,7 @@
 -define(CALL_TIMEOUT, 60*1000). %% 60 seconds
 
 -include("logger.hrl").
--include("ejabberd_stacktrace.hrl").
+
 
 -record(state, {connection :: pid() | undefined,
 		num :: pos_integer(),
@@ -114,9 +114,10 @@ multi(F) ->
 			{error, _} = Err -> Err;
 			Result -> get_result(Result)
 		    end
-	    catch ?EX_RULE(E, R, St) ->
-		    erlang:erase(?TR_STACK),
-		    erlang:raise(E, R, ?EX_STACK(St))
+            catch
+                E:R:St ->
+                    erlang:erase(?TR_STACK),
+                    erlang:raise(E, R, St)
 	    end;
 	_ ->
 	    erlang:error(nested_transaction)
