@@ -41,6 +41,7 @@
 	 abort/1,
 	 restart/1,
 	 use_new_schema/0,
+	 use_multihost_schema/0,
 	 sql_query_to_iolist/1,
 	 sql_query_to_iolist/2,
 	 escape/1,
@@ -70,6 +71,8 @@
 -export([connecting/2, connecting/3,
 	 session_established/2, session_established/3]).
 
+-deprecated({use_new_schema, 0}).
+
 -ifdef(OTP_BELOW_28).
 -ifdef(OTP_BELOW_26).
 %% OTP 25 or lower
@@ -89,7 +92,7 @@
 
 -include("logger.hrl").
 -include("ejabberd_sql_pt.hrl").
--include("ejabberd_stacktrace.hrl").
+
 
 -record(state,
 	{db_ref               :: undefined | db_ref_pid() | odbc_connection_reference(),
@@ -353,8 +356,11 @@ sqlite_file(Host) ->
 	    binary_to_list(File)
     end.
 
+use_multihost_schema() ->
+    ejabberd_option:sql_schema_multihost().
+
 use_new_schema() ->
-    ejabberd_option:new_sql_schema().
+    use_multihost_schema().
 
 -spec get_worker(binary()) -> atom().
 get_worker(Host) ->
@@ -616,19 +622,20 @@ outer_transaction(F, NRestarts, _Reason) ->
 			    {atomic, Res}
 		    end
 	    catch
-		?EX_RULE(throw, {aborted, Reason}, _) when NRestarts > 0 ->
-		    maybe_restart_transaction(F, NRestarts, Reason, true);
-		?EX_RULE(throw, {aborted, Reason}, Stack) when NRestarts =:= 0 ->
-		    StackTrace = ?EX_STACK(Stack),
-		    ?ERROR_MSG("SQL transaction restarts exceeded~n** "
-			       "Restarts: ~p~n** Last abort reason: "
-			       "~p~n** Stacktrace: ~p~n** When State "
-			       "== ~p",
-			       [?MAX_TRANSACTION_RESTARTS, Reason,
-				StackTrace, get(?STATE_KEY)]),
-		    maybe_restart_transaction(F, NRestarts, Reason, true);
-		?EX_RULE(_, Reason, _) ->
-		    maybe_restart_transaction(F, 0, Reason, true)
+                throw:{aborted, Reason}:_ when NRestarts > 0 ->
+                    maybe_restart_transaction(F, NRestarts, Reason, true);
+                throw:{aborted, Reason}:StackTrace when NRestarts =:= 0 ->
+                    ?ERROR_MSG("SQL transaction restarts exceeded~n** "
+                               "Restarts: ~p~n** Last abort reason: "
+                               "~p~n** Stacktrace: ~p~n** When State "
+                               "== ~p",
+                               [?MAX_TRANSACTION_RESTARTS,
+                                Reason,
+                                StackTrace,
+                                get(?STATE_KEY)]),
+                    maybe_restart_transaction(F, NRestarts, Reason, true);
+                _:Reason:_ ->
+                    maybe_restart_transaction(F, 0, Reason, true)
 	    end
     end.
 
@@ -742,10 +749,9 @@ sql_query_internal(#sql_query{} = Query) ->
 		{error, <<"terminated unexpectedly">>};
 	      exit:{shutdown, _} ->
 		{error, <<"shutdown">>};
-	      ?EX_RULE(Class, Reason, Stack) ->
-		StackTrace = ?EX_STACK(Stack),
+            Class:Reason:StackTrace ->
                 ?ERROR_MSG("Internal error while processing SQL query:~n** ~ts",
-			   [misc:format_exception(2, Class, Reason, StackTrace)]),
+                           [misc:format_exception(2, Class, Reason, StackTrace)]),
                 {error, <<"internal error">>}
         end,
     check_error(Res, Query);
@@ -935,12 +941,11 @@ sql_query_format_res({selected, _, Rows}, SQLQuery) ->
                   try
                       [(SQLQuery#sql_query.format_res)(Row)]
                   catch
-		      ?EX_RULE(Class, Reason, Stack) ->
-			  StackTrace = ?EX_STACK(Stack),
+                      Class:Reason:StackTrace ->
                           ?ERROR_MSG("Error while processing SQL query result:~n"
                                      "** Row: ~p~n** ~ts",
                                      [Row,
-				      misc:format_exception(2, Class, Reason, StackTrace)]),
+                                      misc:format_exception(2, Class, Reason, StackTrace)]),
                           []
                   end
           end, Rows),
