@@ -243,6 +243,7 @@ install(Package, Config) when is_binary(Package) ->
                 ok ->
                     code:add_pathsz([module_ebin_dir(Module)|module_deps_dirs(Module)]),
                     ejabberd_config_reload(Config),
+                    maybe_print_module_status(Module),
                     copy_commit_json(Package, Attrs),
                     ModuleRuntime = get_runtime_module_name(Module),
                     case erlang:function_exported(ModuleRuntime, post_install, 0) of
@@ -263,6 +264,14 @@ ejabberd_config_reload(Config) when is_list(Config) ->
 ejabberd_config_reload(undefined) ->
     ejabberd_config:reload().
 
+maybe_print_module_status(Module) ->
+    case get_module_status_el(Module) of
+        [_, {xmlcdata, String}] ->
+            io:format("~ts~n", [String]);
+        _ ->
+            ok
+    end.
+
 uninstall(Module) when is_atom(Module) ->
     uninstall(misc:atom_to_binary(Module));
 uninstall(Package) when is_binary(Package) ->
@@ -669,7 +678,8 @@ maybe_define_lager_macro() ->
     end.
 
 compile_options() ->
-    [verbose, report_errors, report_warnings, debug_info, ?ALL_DEFS]
+    [verbose, report_errors, report_warnings, debug_info, ?ALL_DEFS,
+     {feature, maybe_expr, enable}]
     ++ maybe_define_lager_macro()
     ++ [{i, filename:join(app_dir(App), "include")}
         || App <- [fast_xml, xmpp, p1_utils, ejabberd]]
