@@ -43,10 +43,12 @@
 	 is_mucsub_message/1, best_match/2, pmap/2, peach/2, format_exception/4,
 	 get_my_ipv4_address/0, get_my_ipv6_address/0, parse_ip_mask/1,
 	 crypto_hmac/3, crypto_hmac/4, uri_parse/1, uri_parse/2, uri_quote/1,
+	 uri_decode/1,
          json_encode/1, json_decode/1,
 	 set_proc_label/1,
 	 match_ip_mask/3, format_hosts_list/1, format_cycle/1, delete_dir/1,
-	 semver_to_xxyy/1, logical_processors/0, get_mucsub_event_type/1]).
+	 semver_to_xxyy/1, logical_processors/0, get_mucsub_event_type/1,
+         lists_uniq/1]).
 
 %% Deprecated functions
 -export([decode_base64/1, encode_base64/1]).
@@ -71,45 +73,11 @@
 -type distance_cache() :: #{{string(), string()} => non_neg_integer()}.
 
 -spec uri_parse(binary()|string()) -> {ok, string(), string(), string(), number(), string(), string()} | {error, term()}.
--ifdef(USE_OLD_HTTP_URI).
-uri_parse(URL) when is_binary(URL) ->
-    uri_parse(binary_to_list(URL));
 uri_parse(URL) ->
-    uri_parse(URL, []).
+    yconf:parse_uri(URL).
 
-uri_parse(URL, Protocols) when is_binary(URL) ->
-    uri_parse(binary_to_list(URL), Protocols);
 uri_parse(URL, Protocols) ->
-    case http_uri:parse(URL, [{scheme_defaults, Protocols}]) of
-	{ok, {Scheme, UserInfo, Host, Port, Path, Query}} ->
-	    {ok, atom_to_list(Scheme), UserInfo, Host, Port, Path, Query};
-	{error, _} = E ->
-	    E
-    end.
-
--else.
-uri_parse(URL) when is_binary(URL) ->
-    uri_parse(binary_to_list(URL));
-uri_parse(URL) ->
-    uri_parse(URL, [{http, 80}, {https, 443}]).
-
-uri_parse(URL, Protocols) when is_binary(URL) ->
-    uri_parse(binary_to_list(URL), Protocols);
-uri_parse(URL, Protocols) ->
-    case uri_string:parse(URL) of
-	#{scheme := Scheme, host := Host, port := Port, path := Path} = M1 ->
-	    {ok, Scheme, maps:get(userinfo, M1, ""), Host, Port, Path, maps:get(query, M1, "")};
-	#{scheme := Scheme, host := Host, path := Path} = M2 ->
-	    case lists:keyfind(list_to_atom(Scheme), 1, Protocols) of
-		{_, Port} ->
-		    {ok, Scheme, maps:get(userinfo, M2, ""), Host, Port, Path, maps:get(query, M2, "")};
-		_ ->
-		    {error, unknown_protocol}
-	    end;
-	{error, Atom, _} ->
-	    {error, Atom}
-    end.
--endif.
+    yconf:parse_uri(URL, Protocols).
 
 -ifdef(OTP_BELOW_25).
 -ifdef(OTP_BELOW_24).
@@ -124,6 +92,26 @@ uri_quote(Data) ->
     uri_string:quote(Data).
 -endif.
 
+%% @doc Decode a part of the URL and return string()
+%% -spec url_decode(binary()) -> bitstring().
+
+-ifdef(OTP_BELOW_24).
+uri_decode(Path) -> uri_decode(Path, <<>>).
+
+uri_decode(<<$%, Hi, Lo, Tail/binary>>, Acc) ->
+    Hex = list_to_integer([Hi, Lo], 16),
+    if Hex == 0 -> exit(badurl);
+       true -> ok
+    end,
+    uri_decode(Tail, <<Acc/binary, Hex>>);
+uri_decode(<<H, T/binary>>, Acc) when H /= 0 ->
+    uri_decode(T, <<Acc/binary, H>>);
+uri_decode(<<>>, Acc) -> Acc.
+-else.
+uri_decode(Path) ->
+    uri_string:percent_decode(Path).
+-endif.
+
 -ifdef(USE_OLD_CRYPTO_HMAC).
 crypto_hmac(Type, Key, Data) -> crypto:hmac(Type, Key, Data).
 crypto_hmac(Type, Key, Data, MacL) -> crypto:hmac(Type, Key, Data, MacL).
@@ -138,15 +126,16 @@ json_encode(Term) ->
 json_decode(Bin) ->
     jiffy:decode(Bin, [return_maps]).
 -else.
-json_encode({[{_Key, _Value} | _]} = Term) ->
+json_encode({[]}) ->
+    %% Jiffy was able to handle this case, but Json library does not
+    <<"{}">>;
+json_encode(Term) ->
     iolist_to_binary(json:encode(Term,
 		     fun({Val}, Encoder) when is_list(Val) ->
 			 json:encode_key_value_list(Val, Encoder);
 			(Val, Encoder) ->
 			 json:encode_value(Val, Encoder)
-		     end));
-json_encode(Term) ->
-    iolist_to_binary(json:encode(Term)).
+		     end)).
 json_decode(Bin) ->
     json:decode(Bin).
 -endif.
@@ -819,3 +808,21 @@ set_proc_label(_Label) ->
 set_proc_label(Label) ->
     proc_lib:set_label(Label).
 -endif.
+
+-ifdef(OTP_BELOW_25).
+-spec lists_uniq([term()]) -> [term()].
+lists_uniq(List) ->
+    lists_uniq_int(List, #{}).
+
+lists_uniq_int([El | Rest], Existing) ->
+    case maps:is_key(El, Existing) of
+        true -> lists_uniq_int(Rest, Existing);
+        _ -> [El | lists_uniq_int(Rest, Existing#{El => true})]
+    end;
+lists_uniq_int([], _) ->
+    [].
+-else.
+-spec lists_uniq([term()]) -> [term()].
+lists_uniq(List) ->
+    lists:uniq(List).
+-endif.
