@@ -252,9 +252,11 @@ mod_options(_Host) ->
 
 mod_doc() ->
     #{desc =>
-          ?T("This module implements https://xmpp.org/extensions/xep-0050.html"
+          [?T("def:ad-hoc command"), "",
+           ?T(": Command that can be executed by an XMPP client using XEP-0050."), "",
+           ?T("This module implements https://xmpp.org/extensions/xep-0050.html"
              "[XEP-0050: Ad-Hoc Commands]. It's an auxiliary module and is "
-             "only needed by some of the other modules."),
+             "only needed by some of the other modules.")],
       opts =>
           [{report_commands_node,
             #{value => "true | false",
