@@ -1,7 +1,7 @@
 %%%-------------------------------------------------------------------
 %%% File    : mod_admin_update_sql.erl
 %%% Author  : Alexey Shchepin <alexey@process-one.net>
-%%% Purpose : Convert SQL DB to the new format
+%%% Purpose : Convert the SQL database from singlehost to multihost
 %%% Created :  9 Aug 2017 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
@@ -65,7 +65,7 @@ depends(_Host, _Opts) ->
 
 get_commands_spec() ->
     [#ejabberd_commands{name = update_sql, tags = [sql],
-                        desc = "Convert MS SQL, MySQL or PostgreSQL DB to the new format",
+                        desc = "Convert SQL database from singlehost to multihost (MS SQL, MySQL, PostgreSQL)",
                         note = "improved in 23.04",
                         module = ?MODULE, function = update_sql,
                         args = [],
@@ -119,11 +119,11 @@ update_sql(Host) ->
     end.
 
 check_config() ->
-    case ejabberd_sql:use_new_schema() of
+    case ejabberd_sql:use_multihost_schema() of
         true -> ok;
         false ->
-            ejabberd_config:set_option(new_sql_schema, true),
-            io:format('~nNOTE: you must add "new_sql_schema: true" to ejabberd.yml before next restart~n~n', [])
+            ejabberd_config:set_option(sql_schema_multihost, true),
+            io:format('~nNOTE: you must add "sql_schema_multihost: true" to ejabberd.yml before next restart~n~n', [])
     end.
 
 update_tables(State) ->
@@ -150,8 +150,8 @@ update_tables(State) ->
             drop_index(State, "rosterusers", "i_rosteru_user_jid"),
             drop_index(State, "rosterusers", "i_rosteru_username"),
             drop_index(State, "rosterusers", "i_rosteru_jid"),
-            create_unique_index(State, "rosterusers", "i_rosteru_sh_user_jid", ["server_host", "username", "jid"]),
-            create_index(State, "rosterusers", "i_rosteru_sh_jid", ["server_host", "jid"]),
+            create_unique_index(State, "rosterusers", "i_rosteru_server_host_user_jid", ["server_host", "username", "jid"]),
+            create_index(State, "rosterusers", "i_rosteru_server_host_jid", ["server_host", "jid"]),
             drop_sh_default(State, "rosterusers");
         false ->
             ok
@@ -160,7 +160,7 @@ update_tables(State) ->
     case add_sh_column(State, "rostergroups") of
         true ->
             drop_index(State, "rostergroups", "pk_rosterg_user_jid"),
-            create_index(State, "rostergroups", "i_rosterg_sh_user_jid", ["server_host", "username", "jid"]),
+            create_index(State, "rostergroups", "i_rosterg_server_host_user_jid", ["server_host", "username", "jid"]),
             drop_sh_default(State, "rostergroups");
         false ->
             ok
@@ -169,7 +169,7 @@ update_tables(State) ->
     case add_sh_column(State, "sr_group") of
         true ->
             drop_index(State, "sr_group", "i_sr_group_name"),
-            create_unique_index(State, "sr_group", "i_sr_group_sh_name", ["server_host", "name"]),
+            create_unique_index(State, "sr_group", "i_sr_group_server_host_name", ["server_host", "name"]),
             drop_sh_default(State, "sr_group");
         false ->
             ok
@@ -180,8 +180,8 @@ update_tables(State) ->
             drop_index(State, "sr_user", "i_sr_user_jid_grp"),
             drop_index(State, "sr_user", "i_sr_user_jid"),
             drop_index(State, "sr_user", "i_sr_user_grp"),
-            create_unique_index(State, "sr_user", "i_sr_user_sh_jid_grp", ["server_host", "jid", "grp"]),
-            create_index(State, "sr_user", "i_sr_user_sh_grp", ["server_host", "grp"]),
+            create_unique_index(State, "sr_user", "i_sr_user_server_host_jid_grp", ["server_host", "jid", "grp"]),
+            create_index(State, "sr_user", "i_sr_user_server_host_grp", ["server_host", "grp"]),
             drop_sh_default(State, "sr_user");
         false ->
             ok
@@ -190,7 +190,7 @@ update_tables(State) ->
     case add_sh_column(State, "spool") of
         true ->
             drop_index(State, "spool", "i_despool"),
-            create_index(State, "spool", "i_spool_sh_username", ["server_host", "username"]),
+            create_index(State, "spool", "i_spool_server_host_username", ["server_host", "username"]),
             drop_sh_default(State, "spool");
         false ->
             ok
@@ -205,10 +205,10 @@ update_tables(State) ->
             drop_index(State, "archive", "i_bare_peer"),
             drop_index(State, "archive", "i_username_peer"),
             drop_index(State, "archive", "i_username_bare_peer"),
-            create_index(State, "archive", "i_archive_sh_username_timestamp", ["server_host", "username", "timestamp"]),
-            create_index(State, "archive", "i_archive_sh_timestamp", ["server_host", "timestamp"]),
-            create_index(State, "archive", "i_archive_sh_username_peer", ["server_host", "username", "peer"]),
-            create_index(State, "archive", "i_archive_sh_username_bare_peer", ["server_host", "username", "bare_peer"]),
+            create_index(State, "archive", "i_archive_server_host_username_timestamp", ["server_host", "username", "timestamp"]),
+            create_index(State, "archive", "i_archive_server_host_timestamp", ["server_host", "timestamp"]),
+            create_index(State, "archive", "i_archive_server_host_username_peer", ["server_host", "username", "peer"]),
+            create_index(State, "archive", "i_archive_server_host_username_bare_peer", ["server_host", "username", "bare_peer"]),
             drop_sh_default(State, "archive");
         false ->
             ok
@@ -247,17 +247,17 @@ update_tables(State) ->
             drop_index(State, "vcard_search", "i_vcard_search_lorgname"),
             drop_index(State, "vcard_search", "i_vcard_search_lorgunit"),
             add_pkey(State, "vcard_search", ["server_host", "lusername"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lfn",       ["server_host", "lfn"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lfamily",   ["server_host", "lfamily"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lgiven",    ["server_host", "lgiven"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lmiddle",   ["server_host", "lmiddle"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lnickname", ["server_host", "lnickname"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lbday",     ["server_host", "lbday"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lctry",     ["server_host", "lctry"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_llocality", ["server_host", "llocality"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lemail",    ["server_host", "lemail"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lorgname",  ["server_host", "lorgname"]),
-            create_index(State, "vcard_search", "i_vcard_search_sh_lorgunit",  ["server_host", "lorgunit"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lfn",       ["server_host", "lfn"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lfamily",   ["server_host", "lfamily"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lgiven",    ["server_host", "lgiven"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lmiddle",   ["server_host", "lmiddle"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lnickname", ["server_host", "lnickname"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lbday",     ["server_host", "lbday"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lctry",     ["server_host", "lctry"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_llocality", ["server_host", "llocality"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lemail",    ["server_host", "lemail"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lorgname",  ["server_host", "lorgname"]),
+            create_index(State, "vcard_search", "i_vcard_search_server_host_lorgunit",  ["server_host", "lorgunit"]),
             drop_sh_default(State, "vcard_search");
         false ->
             ok
@@ -276,7 +276,7 @@ update_tables(State) ->
         true ->
             drop_index(State, "privacy_list", "i_privacy_list_username"),
             drop_index(State, "privacy_list", "i_privacy_list_username_name"),
-            create_unique_index(State, "privacy_list", "i_privacy_list_sh_username_name", ["server_host", "username", "name"]),
+            create_unique_index(State, "privacy_list", "i_privacy_list_server_host_username_name", ["server_host", "username", "name"]),
             drop_sh_default(State, "privacy_list");
         false ->
             ok
@@ -345,7 +345,7 @@ update_tables(State) ->
             drop_index(State, "sm", "i_sm_username"),
             drop_pkey(State, "sm"),
             add_pkey(State, "sm", ["usec", "pid"]),
-            create_index(State, "sm", "i_sm_sh_username", ["server_host", "username"]),
+            create_index(State, "sm", "i_sm_server_host_username", ["server_host", "username"]),
             drop_sh_default(State, "sm");
         false ->
             ok
@@ -356,7 +356,7 @@ update_tables(State) ->
             drop_index(State, "push_session", "i_push_usn"),
             drop_index(State, "push_session", "i_push_ut"),
             create_unique_index(State, "push_session", "i_push_session_susn", ["server_host", "username", "service", "node"]),
-            create_index(State, "push_session", "i_push_session_sh_username_timestamp", ["server_host", "username", "timestamp"]),
+            create_index(State, "push_session", "i_push_session_server_host_username_timestamp", ["server_host", "username", "timestamp"]),
             drop_sh_default(State, "push_session");
         false ->
             ok
@@ -523,7 +523,7 @@ create_unique_index(#state{dbtype = pgsql} = State, Table, Index, Cols) ->
       State#state.host,
       ["CREATE UNIQUE INDEX ", Index, " ON ", Table, " USING btree (",
        SCols, ");"]);
-create_unique_index(#state{dbtype = mssql} = State, Table, "i_privacy_list_sh_username_name" = Index, Cols) ->
+create_unique_index(#state{dbtype = mssql} = State, Table, "i_privacy_list_server_host_username_name" = Index, Cols) ->
     create_index(State, Table, Index, Cols);
 create_unique_index(#state{dbtype = mssql} = State, Table, Index, Cols) ->
     SCols = string:join(Cols, ", "),
@@ -581,10 +581,10 @@ old_index_name(mssql, "i_sr_user_jid_grp") -> "sr_user_jid_group";
 old_index_name(mssql, Index) -> string:substr(Index, 3);
 old_index_name(_Type, Index) -> Index.
 
-new_index_name(mssql, "i_rosterg_sh_user_jid") -> "rostergroups_sh_username_jid";
-new_index_name(mssql, "i_rosteru_sh_jid") -> "rosterusers_sh_jid";
-new_index_name(mssql, "i_rosteru_sh_user_jid") -> "rosterusers_sh_username_jid";
-new_index_name(mssql, "i_sr_user_sh_jid_grp") -> "sr_user_sh_jid_group";
+new_index_name(mssql, "i_rosterg_server_host_user_jid") -> "rostergroups_server_host_username_jid";
+new_index_name(mssql, "i_rosteru_server_host_jid") -> "rosterusers_server_host_jid";
+new_index_name(mssql, "i_rosteru_server_host_user_jid") -> "rosterusers_server_host_username_jid";
+new_index_name(mssql, "i_sr_user_server_host_jid_grp") -> "sr_user_server_host_jid_group";
 new_index_name(mssql, Index) -> string:substr(Index, 3);
 new_index_name(_Type, Index) -> Index.
 
@@ -617,9 +617,9 @@ mysql_keylen(_, "pid") -> "(75)";
 mysql_keylen(_, "server_host") -> "(191)";
 mysql_keylen(_, "service") -> "(191)";
 mysql_keylen(_, "topic") -> "(191)";
-mysql_keylen("i_privacy_list_sh_username_name", "username") -> "(75)";
-mysql_keylen("i_rosterg_sh_user_jid", "username") -> "(75)";
-mysql_keylen("i_rosteru_sh_user_jid", "username") -> "(75)";
+mysql_keylen("i_privacy_list_server_host_username_name", "username") -> "(75)";
+mysql_keylen("i_rosterg_server_host_user_jid", "username") -> "(75)";
+mysql_keylen("i_rosteru_server_host_user_jid", "username") -> "(75)";
 mysql_keylen(_, "username") -> "(191)";
 mysql_keylen(_, _) -> "".
 
