@@ -27,7 +27,7 @@
 
 -author('alexey@process-one.net').
 
--protocol({xep, 133, '1.3.0', '13.10', "partial", ""}).
+-protocol({xep, 133, '1.3.1', '13.10', "partial", ""}).
 
 -behaviour(gen_mod).
 
@@ -136,24 +136,48 @@ get_local_identity(Acc, _From, _To, Node, Lang) ->
 	  ?INFO_COMMAND(?T("Add User"), Lang);
       ?NS_ADMINL(<<"delete-user">>) ->
 	  ?INFO_COMMAND(?T("Delete User"), Lang);
+      ?NS_ADMINL(<<"disable-user">>) ->
+	  ?INFO_COMMAND(?T("Disable User"), Lang);
+      ?NS_ADMINL(<<"reenable-user">>) ->
+	  ?INFO_COMMAND(?T("Re-Enable User"), Lang);
       ?NS_ADMINL(<<"end-user-session">>) ->
 	  ?INFO_COMMAND(?T("End User Session"), Lang);
       ?NS_ADMINL(<<"change-user-password">>) ->
 	  ?INFO_COMMAND(?T("Change User Password"), Lang);
+      ?NS_ADMINL(<<"get-user-roster">>) ->
+	  ?INFO_COMMAND(?T("Get User Roster"), Lang);
       ?NS_ADMINL(<<"get-user-lastlogin">>) ->
 	  ?INFO_COMMAND(?T("Get User Last Login Time"), Lang);
       ?NS_ADMINL(<<"user-stats">>) ->
 	  ?INFO_COMMAND(?T("Get User Statistics"), Lang);
-      ?NS_ADMINL(<<"get-registered-users-list">>) ->
-	  ?INFO_COMMAND(?T("Get List of Registered Users"),
-			Lang);
       ?NS_ADMINL(<<"get-registered-users-num">>) ->
 	  ?INFO_COMMAND(?T("Get Number of Registered Users"),
 			Lang);
-      ?NS_ADMINL(<<"get-online-users-list">>) ->
-	  ?INFO_COMMAND(?T("Get List of Online Users"), Lang);
+      ?NS_ADMINL(<<"get-disabled-users-num">>) ->
+	  ?INFO_COMMAND(?T("Get Number of Disabled Users"),
+			Lang);
       ?NS_ADMINL(<<"get-online-users-num">>) ->
 	  ?INFO_COMMAND(?T("Get Number of Online Users"), Lang);
+      ?NS_ADMINL(<<"get-active-users-num">>) ->
+	  ?INFO_COMMAND(?T("Get Number of Active Users"), Lang);
+      ?NS_ADMINL(<<"get-idle-users-num">>) ->
+	  ?INFO_COMMAND(?T("Get Number of Idle Users"), Lang);
+      ?NS_ADMINL(<<"get-registered-users-list">>) ->
+	  ?INFO_COMMAND(?T("Get List of Registered Users"),
+			Lang);
+      ?NS_ADMINL(<<"get-disabled-users-list">>) ->
+	  ?INFO_COMMAND(?T("Get List of Disabled Users"),
+			Lang);
+      ?NS_ADMINL(<<"get-online-users-list">>) ->
+	  ?INFO_COMMAND(?T("Get List of Online Users"), Lang);
+      ?NS_ADMINL(<<"get-active-users">>) ->
+	  ?INFO_COMMAND(?T("Get List of Active Users"), Lang);
+      ?NS_ADMINL(<<"get-idle-users">>) ->
+	  ?INFO_COMMAND(?T("Get List of Idle Users"), Lang);
+      ?NS_ADMINL(<<"restart">>) ->
+	  ?INFO_COMMAND(?T("Restart Service"), Lang);
+      ?NS_ADMINL(<<"shutdown">>) ->
+	  ?INFO_COMMAND(?T("Shut Down Service"), Lang);
       _ -> Acc
     end.
 
@@ -220,21 +244,43 @@ get_local_features(Acc, From,
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    ?NS_ADMINL(<<"delete-user">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"disable-user">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"reenable-user">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    ?NS_ADMINL(<<"end-user-session">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    ?NS_ADMINL(<<"change-user-password">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"get-user-roster">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    ?NS_ADMINL(<<"get-user-lastlogin">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    ?NS_ADMINL(<<"user-stats">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"get-registered-users-num">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"get-disabled-users-num">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"get-online-users-num">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"get-active-users-num">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"get-idle-users-num">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    ?NS_ADMINL(<<"get-registered-users-list">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
-	    ?NS_ADMINL(<<"get-registered-users-num">>) ->
+	    ?NS_ADMINL(<<"get-disabled-users-list">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    ?NS_ADMINL(<<"get-online-users-list">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
-	    ?NS_ADMINL(<<"get-online-users-num">>) ->
+	    ?NS_ADMINL(<<"get-active-users">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"get-idle-users">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"restart">>) ->
+		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
+	    ?NS_ADMINL(<<"shutdown">>) ->
 		?INFO_RESULT(Allow, [?NS_COMMANDS], Lang);
 	    _ -> Acc
 	  end
@@ -447,21 +493,43 @@ get_local_items(Acc, From, #jid{lserver = LServer} = To,
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    ?NS_ADMINL(<<"delete-user">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"disable-user">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"reenable-user">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    ?NS_ADMINL(<<"end-user-session">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    ?NS_ADMINL(<<"change-user-password">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"get-user-roster">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    ?NS_ADMINL(<<"get-user-lastlogin">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    ?NS_ADMINL(<<"user-stats">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"get-registered-users-num">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"get-disabled-users-num">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"get-online-users-num">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"get-active-users-num">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"get-idle-users-num">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    ?NS_ADMINL(<<"get-registered-users-list">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
-	    ?NS_ADMINL(<<"get-registered-users-num">>) ->
+	    ?NS_ADMINL(<<"get-disabled-users-list">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    ?NS_ADMINL(<<"get-online-users-list">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
-	    ?NS_ADMINL(<<"get-online-users-num">>) ->
+	    ?NS_ADMINL(<<"get-active-users">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"get-idle-users">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"restart">>) ->
+		?ITEMS_RESULT(Allow, LNode, {error, Err});
+	    ?NS_ADMINL(<<"shutdown">>) ->
 		?ITEMS_RESULT(Allow, LNode, {error, Err});
 	    _ -> Acc
 	  end
@@ -488,22 +556,41 @@ get_local_items(_Host, [<<"user">>], Server, Lang) ->
      [?NODE(?T("Add User"), (?NS_ADMINX(<<"add-user">>))),
       ?NODE(?T("Delete User"),
 	    (?NS_ADMINX(<<"delete-user">>))),
+      ?NODE(?T("Disable User"),
+	    (?NS_ADMINX(<<"disable-user">>))),
+      ?NODE(?T("Re-Enable User"),
+	    (?NS_ADMINX(<<"reenable-user">>))),
       ?NODE(?T("End User Session"),
 	    (?NS_ADMINX(<<"end-user-session">>))),
       ?NODE(?T("Change User Password"),
 	    (?NS_ADMINX(<<"change-user-password">>))),
+      ?NODE(?T("Get User Roster"),
+	    (?NS_ADMINX(<<"get-user-roster">>))),
       ?NODE(?T("Get User Last Login Time"),
 	    (?NS_ADMINX(<<"get-user-lastlogin">>))),
       ?NODE(?T("Get User Statistics"),
 	    (?NS_ADMINX(<<"user-stats">>))),
-      ?NODE(?T("Get List of Registered Users"),
-	    (?NS_ADMINX(<<"get-registered-users-list">>))),
       ?NODE(?T("Get Number of Registered Users"),
 	    (?NS_ADMINX(<<"get-registered-users-num">>))),
+      ?NODE(?T("Get Number of Disabled Users"),
+	    (?NS_ADMINX(<<"get-disabled-users-num">>))),
+      ?NODE(?T("Get Number of Online Users"),
+	    (?NS_ADMINX(<<"get-online-users-num">>))),
+      ?NODE(?T("Get Number of Active Users"),
+	    (?NS_ADMINX(<<"get-active-users-num">>))),
+      ?NODE(?T("Get Number of Idle Users"),
+	    (?NS_ADMINX(<<"get-idle-users-num">>))),
+      ?NODE(?T("Get List of Registered Users"),
+	    (?NS_ADMINX(<<"get-registered-users-list">>))),
+      ?NODE(?T("Get List of Disabled Users"),
+	    (?NS_ADMINX(<<"get-disabled-users-list">>))),
       ?NODE(?T("Get List of Online Users"),
 	    (?NS_ADMINX(<<"get-online-users-list">>))),
-      ?NODE(?T("Get Number of Online Users"),
-	    (?NS_ADMINX(<<"get-online-users-num">>)))]};
+      ?NODE(?T("Get List of Active Users"),
+	    (?NS_ADMINX(<<"get-active-users">>))),
+      ?NODE(?T("Get List of Idle Users"),
+	    (?NS_ADMINX(<<"get-idle-users">>)))
+     ]};
 get_local_items(_Host, [<<"http:">> | _], _Server,
 		_Lang) ->
     {result, []};
@@ -552,6 +639,10 @@ get_local_items({global, _Host},
 	    <<"running nodes/", ENode/binary, "/backup">>),
       ?NODE(?T("Import Users From jabberd14 Spool Files"),
 	    <<"running nodes/", ENode/binary, "/import">>),
+      ?NODE(?T("Restart Service"),
+	    (?NS_ADMINX(<<"restart">>))),
+      ?NODE(?T("Shut Down Service"),
+	    (?NS_ADMINX(<<"shutdown">>))),
       ?NODE(?T("Restart Service"),
 	    <<"running nodes/", ENode/binary, "/restart">>),
       ?NODE(?T("Shut Down Service"),
@@ -997,6 +1088,24 @@ get_form(_Host, ?NS_ADMINL(<<"delete-user">>), Lang) ->
 				   label = tr(Lang, ?T("Jabber ID")),
 				   required = true,
 				   var = <<"accountjids">>}]}};
+get_form(_Host, ?NS_ADMINL(<<"disable-user">>), Lang) ->
+    {result,
+     #xdata{title = tr(Lang, ?T("Disable User")),
+	    type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'jid-multi',
+				   label = tr(Lang, ?T("Jabber ID")),
+				   required = true,
+				   var = <<"accountjids">>}]}};
+get_form(_Host, ?NS_ADMINL(<<"reenable-user">>), Lang) ->
+    {result,
+     #xdata{title = tr(Lang, ?T("Re-Enable User")),
+	    type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'jid-multi',
+				   label = tr(Lang, ?T("Jabber ID")),
+				   required = true,
+				   var = <<"accountjids">>}]}};
 get_form(_Host, ?NS_ADMINL(<<"end-user-session">>),
 	 Lang) ->
     {result,
@@ -1021,6 +1130,16 @@ get_form(_Host, ?NS_ADMINL(<<"change-user-password">>),
 				   label = tr(Lang, ?T("Password")),
 				   required = true,
 				   var = <<"password">>}]}};
+get_form(_Host, ?NS_ADMINL(<<"get-user-roster">>),
+	 Lang) ->
+    {result,
+     #xdata{title = tr(Lang, ?T("Get User Roster")),
+	    type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'jid-multi',
+				   label = tr(Lang, ?T("Jabber ID")),
+				   required = true,
+				   var = <<"accountjids">>}]}};
 get_form(_Host, ?NS_ADMINL(<<"get-user-lastlogin">>),
 	 Lang) ->
     {result,
@@ -1040,16 +1159,6 @@ get_form(_Host, ?NS_ADMINL(<<"user-stats">>), Lang) ->
 				   label = tr(Lang, ?T("Jabber ID")),
 				   var = <<"accountjid">>,
 				   required = true}]}};
-get_form(Host, ?NS_ADMINL(<<"get-registered-users-list">>), Lang) ->
-    Values = [jid:encode(jid:make(U, Host))
-              || {U, _} <- ejabberd_auth:get_users(Host)],
-    {result, completed,
-     #xdata{type = form,
-	    fields = [?HFIELD(),
-		      #xdata_field{type = 'jid-multi',
-				   label = tr(Lang, ?T("The list of all users")),
-				   var = <<"registereduserjids">>,
-				   values = Values}]}};
 get_form(Host,
 	 ?NS_ADMINL(<<"get-registered-users-num">>), Lang) ->
     Num = integer_to_binary(ejabberd_auth:count_users(Host)),
@@ -1060,6 +1169,68 @@ get_form(Host,
 				   label = tr(Lang, ?T("Number of registered users")),
 				   var = <<"registeredusersnum">>,
 				   values = [Num]}]}};
+get_form(Host,
+	 ?NS_ADMINL(<<"get-disabled-users-num">>), Lang) ->
+    Num = integer_to_binary(mod_admin_extra:count_banned(Host)),
+    {result, completed,
+     #xdata{type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'text-single',
+				   label = tr(Lang, ?T("Number of disabled users")),
+				   var = <<"disabledusersnum">>,
+				   values = [Num]}]}};
+get_form(Host, ?NS_ADMINL(<<"get-online-users-num">>),
+	 Lang) ->
+    Num = integer_to_binary(ejabberd_sm:get_vh_session_number(Host)),
+    {result, completed,
+     #xdata{type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'text-single',
+				   label = tr(Lang, ?T("Number of online users")),
+				   var = <<"onlineusersnum">>,
+				   values = [Num]}]}};
+get_form(Host, ?NS_ADMINL(<<"get-active-users-num">>),
+	 Lang) ->
+    Num = integer_to_binary(mod_admin_extra:status_num(Host, [<<"available">>,
+                                                              <<"chat">>,
+                                                              <<"dnd">>])),
+    {result, completed,
+     #xdata{type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'text-single',
+				   label = tr(Lang, ?T("Number of active users")),
+				   var = <<"activeusersnum">>,
+				   values = [Num]}]}};
+get_form(Host, ?NS_ADMINL(<<"get-idle-users-num">>),
+	 Lang) ->
+    Num = integer_to_binary(mod_admin_extra:status_num(Host, [<<"away">>,
+                                                              <<"xa">>])),
+    {result, completed,
+     #xdata{type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'text-single',
+				   label = tr(Lang, ?T("Number of idle users")),
+				   var = <<"idleusersnum">>,
+				   values = [Num]}]}};
+get_form(Host, ?NS_ADMINL(<<"get-registered-users-list">>), Lang) ->
+    Values = [jid:encode(jid:make(U, Host))
+              || {U, _} <- ejabberd_auth:get_users(Host)],
+    {result, completed,
+     #xdata{type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'jid-multi',
+				   label = tr(Lang, ?T("The list of all users")),
+				   var = <<"registereduserjids">>,
+				   values = Values}]}};
+get_form(Host, ?NS_ADMINL(<<"get-disabled-users-list">>), Lang) ->
+    Values = mod_admin_extra:list_banned(Host),
+    {result, completed,
+     #xdata{type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'jid-multi',
+				   label = tr(Lang, ?T("The list of all disabled users")),
+				   var = <<"disableduserjids">>,
+				   values = Values}]}};
 get_form(Host, ?NS_ADMINL(<<"get-online-users-list">>), Lang) ->
     Accounts = [jid:encode(jid:make(U, Host))
               || {U, _, _} <- ejabberd_sm:get_vh_session_list(Host)],
@@ -1071,16 +1242,36 @@ get_form(Host, ?NS_ADMINL(<<"get-online-users-list">>), Lang) ->
 				   label = tr(Lang, ?T("The list of all online users")),
 				   var = <<"onlineuserjids">>,
 				   values = Values}]}};
-get_form(Host, ?NS_ADMINL(<<"get-online-users-num">>),
-	 Lang) ->
-    Num = integer_to_binary(ejabberd_sm:get_vh_session_number(Host)),
+get_form(Host, ?NS_ADMINL(<<"get-active-users">>), Lang) ->
+    RR = mod_admin_extra:status_list(Host, [<<"available">>, <<"chat">>, <<"dnd">>]),
+    Accounts = [jid:encode(jid:make(U, S))
+              || {U, S, _Resource, _Priority, _StatusText} <- RR],
+    Values = lists:usort(Accounts),
     {result, completed,
      #xdata{type = form,
 	    fields = [?HFIELD(),
-		      #xdata_field{type = 'text-single',
-				   label = tr(Lang, ?T("Number of online users")),
-				   var = <<"onlineusersnum">>,
-				   values = [Num]}]}};
+		      #xdata_field{type = 'jid-multi',
+				   label = tr(Lang, ?T("The list of all active users")),
+				   var = <<"activeuserjids">>,
+				   values = Values}]}};
+get_form(Host, ?NS_ADMINL(<<"get-idle-users">>), Lang) ->
+    RR = mod_admin_extra:status_list(Host, [<<"away">>, <<"xa">>]),
+    Accounts = [jid:encode(jid:make(U, S))
+              || {U, S, _Resource, _Priority, _StatusText} <- RR],
+    Values = lists:usort(Accounts),
+    {result, completed,
+     #xdata{type = form,
+	    fields = [?HFIELD(),
+		      #xdata_field{type = 'jid-multi',
+				   label = tr(Lang, ?T("The list of all idle users")),
+				   var = <<"idleuserjids">>,
+				   values = Values}]}};
+get_form(Host, ?NS_ADMINL(<<"restart">>), Lang) ->
+    get_form(Host,
+	 [<<"running nodes">>, misc:atom_to_binary(node()), <<"restart">>], Lang);
+get_form(Host, ?NS_ADMINL(<<"shutdown">>), Lang) ->
+    get_form(Host,
+	 [<<"running nodes">>, misc:atom_to_binary(node()), <<"shutdown">>], Lang);
 get_form(_Host, _, _Lang) ->
     {error, xmpp:err_service_unavailable()}.
 
@@ -1298,6 +1489,42 @@ set_form(From, Host, ?NS_ADMINL(<<"delete-user">>),
     [ejabberd_auth:remove_user(User, Server)
      || {User, Server} <- ASL2],
     {result, undefined};
+set_form(From, Host, ?NS_ADMINL(<<"disable-user">>),
+	 _Lang, XData) ->
+    AccountStringList = get_values(<<"accountjids">>,
+				   XData),
+    [_ | _] = AccountStringList,
+    ASL2 = lists:map(fun (AccountString) ->
+			     JID = jid:decode(AccountString),
+			     User = JID#jid.luser,
+			     Server = JID#jid.lserver,
+			     true = Server == Host orelse
+				      get_permission_level(From, Host) == global,
+			     true = ejabberd_auth:user_exists(User, Server),
+			     {User, Server}
+		     end,
+		     AccountStringList),
+    [mod_admin_extra:ban_account_v2(User, Server, <<"">>)
+     || {User, Server} <- ASL2],
+    {result, undefined};
+set_form(From, Host, ?NS_ADMINL(<<"reenable-user">>),
+	 _Lang, XData) ->
+    AccountStringList = get_values(<<"accountjids">>,
+				   XData),
+    [_ | _] = AccountStringList,
+    ASL2 = lists:map(fun (AccountString) ->
+			     JID = jid:decode(AccountString),
+			     User = JID#jid.luser,
+			     Server = JID#jid.lserver,
+			     true = Server == Host orelse
+				      get_permission_level(From, Host) == global,
+			     true = ejabberd_auth:user_exists(User, Server),
+			     {User, Server}
+		     end,
+		     AccountStringList),
+    [mod_admin_extra:unban_account(User, Server)
+     || {User, Server} <- ASL2],
+    {result, undefined};
 set_form(From, Host, ?NS_ADMINL(<<"end-user-session">>),
 	 _Lang, XData) ->
     AccountString = get_value(<<"accountjid">>, XData),
@@ -1324,6 +1551,31 @@ set_form(From, Host,
     true = ejabberd_auth:user_exists(User, Server),
     ejabberd_auth:set_password(User, Server, Password),
     {result, undefined};
+set_form(From, Host,
+	 ?NS_ADMINL(<<"get-user-roster">>), Lang, XData) ->
+    AccountStringList = get_values(<<"accountjids">>,
+				   XData),
+    [_ | _] = AccountStringList,
+    ASL2 = lists:map(fun (AccountString) ->
+			     JID = jid:decode(AccountString),
+			     User = JID#jid.luser,
+			     Server = JID#jid.lserver,
+			     true = Server == Host orelse
+				      get_permission_level(From, Host) == global,
+			     true = ejabberd_auth:user_exists(User, Server),
+			     {User, Server}
+		     end,
+		     AccountStringList),
+    Contacts = [mod_admin_extra:get_roster(User, Server) || {User, Server} <- ASL2],
+    Jids = [lists:join(<<"; ">>, [Jid, Name, Subscription, lists:join(<<", ">>, Groups)])
+            || {Jid, Name, Subscription, _, Groups} <- lists:flatten(Contacts)],
+    {result,
+     #xdata{type = result,
+	    fields = [?HFIELD(),
+		      ?XMFIELD('jid-multi', ?T("Jabber ID"),
+			      <<"accountjids">>, AccountStringList),
+		      ?XMFIELD('text-multi', ?T("Contacts"),
+			       <<"contacts">>, Jids)]}};
 set_form(From, Host,
 	 ?NS_ADMINL(<<"get-user-lastlogin">>), Lang, XData) ->
     AccountString = get_value(<<"accountjid">>, XData),
@@ -1350,7 +1602,7 @@ set_form(From, Host,
 	      _ -> tr(Lang, ?T("Online"))
 	    end,
     {result,
-     #xdata{type = form,
+     #xdata{type = result,
 	    fields = [?HFIELD(),
 		      ?XFIELD('jid-single', ?T("Jabber ID"),
 			      <<"accountjid">>, AccountString),
@@ -1375,7 +1627,7 @@ set_form(From, Host, ?NS_ADMINL(<<"user-stats">>), Lang,
 				    [{User, Server}]),
     Rostersize = integer_to_binary(erlang:length(Items)),
     {result,
-     #xdata{type = form,
+     #xdata{type = result,
 	    fields = [?HFIELD(),
 		      ?XFIELD('jid-single', ?T("Jabber ID"),
 			      <<"accountjid">>, AccountString),
@@ -1385,6 +1637,14 @@ set_form(From, Host, ?NS_ADMINL(<<"user-stats">>), Lang,
 			       <<"ipaddresses">>, IPs),
 		      ?XMFIELD('text-multi', ?T("Resources"),
 			       <<"onlineresources">>, Resources)]}};
+set_form(From, Host, ?NS_ADMINL(<<"restart">>), Lang,
+	 XData) ->
+    set_form(From, Host,
+	 [<<"running nodes">>, misc:atom_to_binary(node()), <<"restart">>], Lang, XData);
+set_form(From, Host, ?NS_ADMINL(<<"shutdown">>), Lang,
+	 XData) ->
+    set_form(From, Host,
+	 [<<"running nodes">>, misc:atom_to_binary(node()), <<"shutdown">>], Lang, XData);
 set_form(_From, _Host, _, _Lang, _XData) ->
     {error, xmpp:err_service_unavailable()}.
 
@@ -1544,28 +1804,40 @@ mod_opt_type(access) ->
 mod_options(_Host) ->
     [{access, configure}].
 
-%% @format-begin
-
 %% All ad-hoc commands implemented by mod_configure are available as API Commands:
 %% - add-user                  -> register
 %% - delete-user               -> unregister
+%% - disable-user              -> ban_account
+%% - reenable-user             -> unban_account
 %% - end-user-session          -> kick_session / kick_user
 %% - change-user-password      -> change_password
 %% - get-user-lastlogin        -> get_last
+%% - get-user-roster           -> get_roster
+%% - get-user-lastlogin        -> get_last
 %% - user-stats                -> user_sessions_info
-%% - get-registered-users-list -> registered_users
+%% - edit-blacklist            -> not ad-hoc or API command available !!!
+%% - edit-whitelist            -> not ad-hoc or API command available !!!
 %% - get-registered-users-num  -> stats
-%% - get-online-users-list     -> connected_users
+%% - get-disabled-users-num    -> count_banned
 %% - get-online-users-num      -> stats
+%% - get-active-users-num      -> status_num
+%% - get-idle-users-num        -> status_num
+%% - get-registered-users-list -> registered_users
+%% - get-disabled-users-list   -> list_banned
+%% - get-online-users-list     -> connected_users
+%% - get-active-users          -> status_list
+%% - get-idle-users            -> status_list
 %% - stopped nodes             -> list_cluster_detailed
 %% - DB                        -> mnesia_list_tables and mnesia_table_change_storage
-%% - restart                   -> stop_kindly / restart
+%% - edit-admin                -> not ad-hoc or API command available !!!
+%% - restart                   -> restart_kindly
 %% - shutdown                  -> stop_kindly
 %% - backup                    -> backup
 %% - restore                   -> restore
 %% - textfile                  -> dump
 %% - import/file               -> import_file
 %% - import/dir                -> import_dir
+
 %%
 %% An exclusive feature available only in this module is to list items and discover them:
 %% - outgoing s2s
@@ -1579,9 +1851,28 @@ mod_doc() ->
               "https://xmpp.org/extensions/xep-0050.html[XEP-0050: Ad-Hoc Commands]:"),
            "",
            "- List and discover outgoing s2s, online client sessions and all registered accounts",
-           "- Most of the ad-hoc commands defined in https://xmpp.org/extensions/xep-0133.html[XEP-0133: Service Administration]",
+           "- Most of the ad-hoc commands defined in "
+           "  https://xmpp.org/extensions/xep-0133.html[XEP-0133: Service Administration]",
            "- Additional custom ad-hoc commands specific to ejabberd",
            "",
+           ?T("Ad-hoc commands from XEP-0133 that behave differently to the XEP:"),
+           "",
+           " - `get-user-roster`: returns standard fields instead of roster items that client cannot display",
+           "",
+           ?T("Those ad-hoc commands from XEP-0133 do not include in the response "
+              "the client that executed the command:"),
+           "",
+           " - `get-active-users-num`",
+           " - `get-idle-users-num`",
+           " - `get-active-users`",
+           " - `get-idle-users`",
+           "",
+           ?T("Those ad-hoc commands from XEP-0133 are not implemented:"),
+           "",
+           " - `edit-blacklist`",
+           " - `edit-whitelist`",
+           " - `edit-admin`",
+           "",
            ?T("This module requires _`mod_adhoc`_ (to execute the commands), "
               "and recommends _`mod_disco`_ (to discover the commands). "),
            "",
@@ -1589,6 +1880,7 @@ mod_doc() ->
               "have an equivalent "
               "https://docs.ejabberd.im/developer/ejabberd-api/[API Command] "
               "that you can execute using _`mod_adhoc_api`_ or any other API frontend.")],
+      note => "improved in 25.10",
       opts =>
           [{access,
             #{value => ?T("AccessName"),
