@@ -36,7 +36,7 @@
 -include_lib("xmpp/include/xmpp.hrl").
 -include("logger.hrl").
 -include("ejabberd_http.hrl").
--include("ejabberd_stacktrace.hrl").
+
 -include("translate.hrl").
 
 -define(DEFAULT_API_VERSION, 1000000).
@@ -145,12 +145,11 @@ process([Call | _], #request{method = 'POST', data = Data, ip = IPPort} = Req) -
         %% TODO We need to refactor to remove redundant error return formatting
         throw:{error, unknown_command} ->
             json_format({404, 44, <<"Command not found.">>});
-        _:{error,{_,invalid_json}} = _Err ->
-	    ?DEBUG("Bad Request: ~p", [_Err]),
+        _:{error,{_,invalid_json}} = Err ->
+	    ?DEBUG("Bad Request: ~p", [Err]),
 	    badrequest_response(<<"Invalid JSON input">>);
-	?EX_RULE(_Class, _Error, Stack) ->
-	    StackTrace = ?EX_STACK(Stack),
-            ?DEBUG("Bad Request: ~p ~p", [_Error, StackTrace]),
+        _Class:Error:StackTrace ->
+            ?DEBUG("Bad Request: ~p ~p", [Error, StackTrace]),
             badrequest_response()
     end;
 process([Call | _], #request{method = 'GET', q = Data, ip = {IP, _}} = Req) ->
@@ -166,9 +165,8 @@ process([Call | _], #request{method = 'GET', q = Data, ip = {IP, _}} = Req) ->
         %% TODO We need to refactor to remove redundant error return formatting
         throw:{error, unknown_command} ->
             json_format({404, 44, <<"Command not found.">>});
-        ?EX_RULE(_, _Error, Stack) ->
-	    StackTrace = ?EX_STACK(Stack),
-            ?DEBUG("Bad Request: ~p ~p", [_Error, StackTrace]),
+        _:Error:StackTrace ->
+            ?DEBUG("Bad Request: ~p ~p", [Error, StackTrace]),
             badrequest_response()
     end;
 process([_Call], #request{method = 'OPTIONS', data = <<>>}) ->
@@ -257,13 +255,15 @@ handle(Call, Auth, Args, Version) when is_atom(Call), is_list(Args) ->
 	    {400, misc:atom_to_binary(Error)};
 	  throw:Msg when is_list(Msg); is_binary(Msg) ->
 	    {400, iolist_to_binary(Msg)};
-	  ?EX_RULE(Class, Error, Stack) ->
-	    StackTrace = ?EX_STACK(Stack),
-	    ?ERROR_MSG("REST API Error: "
-		       "~ts(~p) -> ~p:~p ~p",
-		       [Call, hide_sensitive_args(Args),
-			Class, Error, StackTrace]),
-	    {500, <<"internal_error">>}
+        Class:Error:StackTrace ->
+            ?ERROR_MSG("REST API Error: "
+                       "~ts(~p) -> ~p:~p ~p",
+                       [Call,
+                        hide_sensitive_args(Args),
+                        Class,
+                        Error,
+                        StackTrace]),
+            {500, <<"internal_error">>}
     end.
 
 handle2(Call, Auth, Args, Version) when is_atom(Call), is_list(Args) ->
@@ -372,8 +372,8 @@ format_arg({[{Name, Value}]},
 format_arg(Elements,
 	   {tuple, ElementsDef})
   when is_map(Elements) ->
-    list_to_tuple([element(2, maps:find(atom_to_binary(Name, latin1), Elements))
-                   || {Name, _Format} <- ElementsDef]);
+    list_to_tuple([format_arg(element(2, maps:find(atom_to_binary(Name, latin1), Elements)), Format)
+                   || {Name, Format} <- ElementsDef]);
 
 format_arg({Elements},
 	   {tuple, ElementsDef})
@@ -401,9 +401,15 @@ format_arg(Arg, integer) when is_integer(Arg) -> Arg;
 format_arg(Arg, integer) when is_binary(Arg) -> binary_to_integer(Arg);
 format_arg(Arg, binary) when is_list(Arg) -> process_unicode_codepoints(Arg);
 format_arg(Arg, binary) when is_binary(Arg) -> Arg;
+format_arg([], binary_or_list) -> [];
+format_arg([First | _] = Arg, binary_or_list) when is_binary(First) -> Arg;
+format_arg([First | _] = Arg, binary_or_list) when is_integer(First) ->
+    [process_unicode_codepoints(Arg)];
+format_arg(Arg, binary_or_list) when is_binary(Arg) -> [Arg];
 format_arg(Arg, string) when is_list(Arg) -> Arg;
 format_arg(Arg, string) when is_binary(Arg) -> binary_to_list(Arg);
 format_arg(undefined, binary) -> <<>>;
+format_arg(undefined, binary_or_list) -> [];
 format_arg(undefined, string) -> "";
 format_arg(Arg, Format) ->
     ?ERROR_MSG("Don't know how to format Arg ~p for format ~p", [Arg, Format]),
