@@ -32,6 +32,8 @@
 	 muc_online_rooms/1, muc_online_rooms_by_regex/2,
 	 muc_register_nick/3, muc_register_nick/4,
 	 muc_unregister_nick/2, muc_unregister_nick/3,
+         muc_get_registered_nick/3,
+         muc_get_registered_nicks/1,
 	 create_room_with_opts/4, create_room/3, destroy_room/2,
 	 create_rooms_file/1, destroy_rooms_file/1,
 	 rooms_unused_list/2, rooms_unused_destroy/2,
@@ -159,6 +161,30 @@ get_commands_spec() ->
 		       args = [{user, binary}, {host, binary}, {service, binary}],
 		       args_rename = [{host, service}],
 		       result = {res, rescode}},
+     #ejabberd_commands{name = muc_get_registered_nick, tags = [muc],
+		       desc = "Get nick registered for that account in the MUC service",
+		       module = ?MODULE, function = muc_get_registered_nick,
+		       note = "added in 25.10",
+		       args_desc = ["user name", "user host", "MUC service"],
+		       args_example = [<<"tim">>, <<"example.org">>, <<"conference.example.org">>],
+		       args = [{user, binary}, {host, binary}, {service, binary}],
+		       result_desc = "nick registered",
+		       result_example = ["Tim"],
+		       result = {nick, string}},
+     #ejabberd_commands{name = muc_get_registered_nicks, tags = [muc],
+		       desc = "List all nicks registered in the MUC service",
+		       module = ?MODULE, function = muc_get_registered_nicks,
+		       note = "added in 25.10",
+		       args_desc = ["MUC service"],
+		       args_example = [<<"conference.example.org">>],
+		       args = [{service, binary}],
+		       result_example = [{"Tim", "timexa", "example.com"},
+					 {"Laia", "laia001", "example2.org"}],
+		       result = {registrations, {list, {registration, {tuple,
+							  [{user, string},
+							   {host, string},
+                                                           {nick, string}
+							  ]}}}}},
 
      #ejabberd_commands{name = create_room, tags = [muc_room],
 		       desc = "Create a MUC room name@service in host",
@@ -696,6 +722,17 @@ muc_unregister_nick(User, Host, Service) ->
 muc_unregister_nick(FromBinary, Service) ->
     muc_register_nick(<<"">>, FromBinary, Service).
 
+muc_get_registered_nick(User, Host, Service) ->
+    MucServerHost = get_room_serverhost(Service),
+    case mod_muc:get_register_nick(MucServerHost, Service, jid:make(User, Host)) of
+        error -> <<"">>;
+        N -> N
+    end.
+
+muc_get_registered_nicks(Service) ->
+    MucServerHost = get_room_serverhost(Service),
+    mod_muc:get_register_nicks(MucServerHost, Service).
+
 get_user_rooms(User, Server) ->
     lists:flatmap(
       fun(ServerHost) ->
@@ -790,9 +827,22 @@ webadmin_muc_host(_Host,
     Title = ?H1GL(PageTitle, <<"modules/#mod_muc">>, <<"mod_muc">>),
     Breadcrumb =
         make_breadcrumb({service_section, Level, Service, <<"Nick Register">>, RPath}),
-    Set = [make_command(muc_register_nick, R, [{<<"service">>, Service}], []),
-           make_command(muc_unregister_nick, R, [{<<"service">>, Service}], [])],
-    Title ++ Breadcrumb ++ Set;
+
+    Set = [make_command(muc_register_nick, R, [{<<"service">>, Service}], [])],
+    %% Execute twice: first to perform the action, the second to get new roster
+    _ = make_webadmin_roster_table(Service, R, RPath),
+    RV2 = make_webadmin_roster_table(Service, R, RPath),
+    Get = [make_command(muc_get_registered_nicks,
+                        R,
+                        [{<<"service">>, Service}],
+                        [{only, presentation}]),
+           ?XE(<<"blockquote">>,
+               [make_command(muc_unregister_nick,
+                             R,
+                             [{<<"service">>, Service}],
+                             [{only, presentation}])]),
+           RV2],
+    Title ++ Breadcrumb ++ Set ++ Get;
 webadmin_muc_host(_Host,
                   Service,
                   [<<"rooms-empty">> | RPath],
@@ -1263,6 +1313,45 @@ web_page_hostuser(Acc, _, _, _) ->
     Acc.
 %% @format-end
 
+%%--------------------
+%% Web Admin Nick Register
+
+%% @format-begin
+make_webadmin_roster_table(Service, R, RPath) ->
+    Nicks =
+        case make_command_raw_value(muc_get_registered_nicks, R, [{<<"service">>, Service}]) of
+            Ns when is_list(Ns) ->
+                Ns;
+            _ ->
+                []
+        end,
+    Level = 4 + length(RPath),
+    Columns = [<<"user@host">>, <<"nick">>, <<"">>],
+    Rows =
+        lists:map(fun({User, Host, Nick}) ->
+                     {make_command(echo,
+                                   R,
+                                   [{<<"sentence">>,
+                                     jid:encode(
+                                         jid:make(User, Host))}],
+                                   [{only, raw_and_value},
+                                    {result_links, [{sentence, user, Level, <<"">>}]}]),
+                      ?C(Nick),
+                      make_command(muc_unregister_nick,
+                                   R,
+                                   [{<<"user">>, User},
+                                    {<<"host">>, Host},
+                                    {<<"service">>, Service}],
+                                   [{only, button},
+                                    {style, danger},
+                                    {input_name_append, [User, Host, Service]}])}
+                  end,
+                  lists:keysort(1, Nicks)),
+    Table = make_table(20, RPath, Columns, Rows),
+    ?XE(<<"blockquote">>, [Table]).
+%% @format-end
+
+
 %%----------------------------
 %% Create/Delete Room
 %%----------------------------
@@ -1289,6 +1378,8 @@ create_room_with_opts(Name1, Host1, ServerHost1, CustomRoomOpts) ->
 		{error, _} ->
 		    throw({error, "Unable to start room"})
 	    end;
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	_ ->
 	    throw({error, "Room already exists"})
     end.
@@ -1307,6 +1398,8 @@ destroy_room(Name1, Service1) ->
     case get_room_pid_validate(Name1, Service1, <<"service">>) of
 	{room_not_found, _, _} ->
 	    throw({error, "Room doesn't exists"});
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	{Pid, _, _} ->
 	    mod_muc_room:destroy(Pid),
 	    ok
@@ -1698,6 +1791,8 @@ change_room_option(Name, Service, OptionString, ValueString) ->
     case get_room_pid_validate(Name, Service, <<"service">>) of
 	{room_not_found, _, _} ->
 	    throw({error, "Room not found"});
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	{Pid, _, _} ->
 	    {Option, Value} = format_room_option(OptionString, ValueString),
 	    change_room_option(Pid, Option, Value)
@@ -1823,25 +1918,29 @@ parse_nodes(_, _) ->
     throw({error, "Invalid 'subscribers' - unknown node name used"}).
 
 -spec get_room_pid_validate(binary(), binary(), binary()) ->
-    {pid() | room_not_found, binary(), binary()}.
+    {pid() | room_not_found | db_failure, binary(), binary()}.
 get_room_pid_validate(Name, Service, ServiceArg) ->
     Name2 = validate_room(Name),
     {ServerHost, Service2} = validate_muc2(Service, ServiceArg),
     case mod_muc:unhibernate_room(ServerHost, Service2, Name2) of
-	error ->
+	{error, notfound} ->
 	    {room_not_found, Name2, Service2};
+	{error, db_failure} ->
+	    {db_failure, Name2, Service2};
 	{ok, Pid} ->
 	    {Pid, Name2, Service2}
     end.
 
 %% @doc Get the Pid of an existing MUC room, or 'room_not_found'.
--spec get_room_pid(binary(), binary()) -> pid() | room_not_found | invalid_service | unknown_service.
+-spec get_room_pid(binary(), binary()) -> pid() | room_not_found | db_failure | invalid_service | unknown_service.
 get_room_pid(Name, Service) ->
     try get_room_serverhost(Service) of
 	ServerHost ->
 	    case mod_muc:unhibernate_room(ServerHost, Service, Name) of
-		error ->
+		{error, notfound} ->
 		    room_not_found;
+		{error, db_failure} ->
+		    db_failure;
 		{ok, Pid} ->
 		    Pid
 	    end
@@ -1954,6 +2053,8 @@ get_room_affiliations(Name, Service) ->
 		 ({{Uname, Domain, _Res}, Aff}) when is_atom(Aff)->
 		      {Uname, Domain, Aff, <<>>}
 	      end, Affiliations);
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	_ ->
 	    throw({error, "The room does not exist."})
     end.
@@ -1975,6 +2076,8 @@ get_room_affiliations_v3(Name, Service) ->
 		      Jid = makeencode(Uname, Domain),
 		      {Jid, Aff, <<>>}
 	      end, Affiliations);
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	_ ->
 	    throw({error, "The room does not exist."})
     end.
@@ -1993,6 +2096,8 @@ get_room_history(Name, Service) ->
 		_ ->
 		    throw({error, "Unable to fetch room state."})
 	    end;
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	_ ->
 	    throw({error, "The room does not exist."})
     end.
@@ -2012,6 +2117,8 @@ get_room_affiliation(Name, Service, JID) ->
 	    {ok, StateData} = mod_muc_room:get_state(Pid),
 	    UserJID = jid:decode(JID),
 	    mod_muc_room:get_affiliation(UserJID, StateData);
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	_ ->
 	    throw({error, "The room does not exist."})
     end.
@@ -2052,6 +2159,8 @@ set_room_affiliation(Name, Service, JID, AffiliationString) ->
 		{error, _} ->
 		    throw({error, "Unable to perform change"})
 	    end;
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	_ ->
 	    throw({error, "Room doesn't exists"})
     end.
@@ -2084,6 +2193,8 @@ subscribe_room(User, Nick, Room, NodeList) ->
 				{error, Reason} ->
 				    throw({error, binary_to_list(Reason)})
 			    end;
+			{db_failure, _Name, _Host} ->
+			    throw({error, "Database error"});
 			_ ->
 			    throw({error, "The room does not exist"})
 		    end
@@ -2129,6 +2240,8 @@ unsubscribe_room(User, Room) ->
 				{error, Reason} ->
 				    throw({error, binary_to_list(Reason)})
 			    end;
+			{db_failure, _Name, _Host} ->
+			    throw({error, "Database error"});
 			_ ->
 			    throw({error, "The room does not exist"})
 		    end
@@ -2146,6 +2259,8 @@ get_subscribers(Name, Host) ->
 	{Pid, _, _} when is_pid(Pid) ->
 	    {ok, JIDList} = mod_muc_room:get_subscribers(Pid),
 	    [jid:encode(jid:remove_resource(J)) || J <- JIDList];
+	{db_failure, _Name, _Host} ->
+	    throw({error, "Database error"});
 	_ ->
 	    throw({error, "The room does not exist"})
     end.
