@@ -28,7 +28,8 @@
 
 %% API
 -export([init/2, set_data/3, get_data/3, get_all_data/2, del_data/2,
-	 use_cache/1, import/3]).
+	del_data/3, get_users_with_data/2, count_users_with_data/2,
+	use_cache/1, import/3]).
 -export([need_transform/1, transform/1]).
 
 -include_lib("xmpp/include/xmpp.hrl").
@@ -101,6 +102,29 @@ del_data(LUser, LServer) ->
 	end,
     transaction(F).
 
+-spec del_data(binary(), binary(), binary()) -> ok | {error, any()}.
+del_data(LUser, LServer, NS) ->
+    F = fun () ->
+		mnesia:delete({private_storage, {LUser, LServer, NS}})
+	end,
+    transaction(F).
+
+-spec get_users_with_data(binary(), binary()) -> {ok, [binary()]} | {error, any()}.
+get_users_with_data(LServer, NS) ->
+	Val = mnesia:dirty_select(private_storage,
+				   [{#private_storage{usns =
+							  {'$1',
+							   LServer,
+							   NS},
+						      _ = '_'},
+				     [], ['$1']}]),
+	{ok, Val}.
+
+-spec count_users_with_data(binary(), binary()) -> {ok, integer()} | {error, any()}.
+count_users_with_data(LServer, NS) ->
+	{ok, Val} = get_users_with_data(LServer, NS),
+	{ok, length(Val)}.
+
 import(LServer, <<"private_storage">>,
        [LUser, XMLNS, XML, _TimeStamp]) ->
     El = #xmlel{} = fxml_stream:parse_element(XML),
