@@ -526,12 +526,20 @@ notify(LServer, PushLJID, Node, XData, Pkt0, Dir, HandleResponse) ->
 	    Item = #ps_item{sub_els = [#push_notification{xdata = Summary}]},
 	    PubSub = #pubsub{publish = #ps_publish{node = Node, items = [Item]},
 			     publish_options = XData},
-	    IQ = #iq{type = set,
-		     from = From,
-		     to = jid:make(PushLJID),
-		     id = p1_rand:get_string(),
-		     sub_els = [PubSub]},
-	    ejabberd_router:route_iq(IQ, HandleResponse)
+	    IQ0 = #iq{type = set,
+		      from = From,
+		      to = jid:make(PushLJID),
+		      id = p1_rand:get_string(),
+		      sub_els = [PubSub]},
+	    case ejabberd_hooks:run_fold(push_send_notification,
+					 LServer, IQ0, [Pkt]) of
+	      drop ->
+		    ?DEBUG("Notification dropped by hook", []),
+		    ok;
+		IQ ->
+		    ?DEBUG("Sending notification: ~n~ts", [xmpp:pp(IQ)]),
+		    ejabberd_router:route_iq(IQ, HandleResponse)
+	    end
     end.
 
 %%--------------------------------------------------------------------
