@@ -61,7 +61,7 @@
 -include("mod_roster.hrl").
 -include("ejabberd_http.hrl").
 -include("ejabberd_web_admin.hrl").
--include("ejabberd_stacktrace.hrl").
+
 -include("translate.hrl").
 
 -define(ROSTER_CACHE, roster_cache).
@@ -1192,7 +1192,7 @@ import_stop(_LServer, _DBType) ->
     ok.
 
 row_length() ->
-    case ejabberd_sql:use_new_schema() of
+    case ejabberd_sql:use_multihost_schema() of
         true -> 10;
         false -> 9
     end.
