@@ -5,7 +5,7 @@
 %%% Created :  5 Mar 2005 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2024   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2025   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -381,7 +381,7 @@ create_group(Host, Group) ->
     create_group(Host, Group, []).
 
 create_group(Host, Group, Opts) ->
-    case jid:nodeprep(Group) of
+    case jid:nameprep(Group) of
 	error ->
 	    {error, invalid_group_name};
 	LGroup ->
@@ -439,8 +439,7 @@ get_group_opts(Host1, Group1) ->
     {Host, Group} = split_grouphost(Host1, Group1),
     get_group_opts_int(Host, Group).
 
-get_group_opts_int(Host1, Group1) ->
-    {Host, Group} = split_grouphost(Host1, Group1),
+get_group_opts_int(Host, Group) ->
     Mod = gen_mod:db_mod(Host, ?MODULE),
     Res = case use_cache(Mod, Host) of
 	true ->
