@@ -71,7 +71,13 @@ end_per_suite(_Config) ->
     application:stop(ejabberd).
 
 init_per_group(Group, Config) ->
-    case lists:member(Group, ?BACKENDS) of
+    BackendOfGroup = case Group of
+                         component -> agnostic;
+                         no_db -> agnostic;
+                         s2s -> agnostic;
+                         _ -> Group
+                     end,
+    case lists:member(BackendOfGroup, ?BACKENDS) of
         false ->
             %% Not a backend related group, do default init:
             do_init_per_group(Group, Config);
@@ -82,7 +88,7 @@ init_per_group(Group, Config) ->
                     do_init_per_group(Group, Config);
                 Backends ->
                     %% Skipped backends that were not explicitly enabled
-		    case lists:member(Group, Backends) of
+		    case lists:member(BackendOfGroup, Backends) of
 			true ->
 			    do_init_per_group(Group, Config);
 			false ->
@@ -961,8 +967,6 @@ presence_broadcast(Config) ->
 	     sub_els = [#disco_info{node = Node}]} = recv_iq(Config),
     #message{type = chat,
              subject = [#text{lang = <<"en">>,data = <<"Welcome!">>}]} = recv_message(Config),
-    #message{type = normal,
-             subject = [#text{lang = <<"en">>,data = <<"Welcome!">>}]} = recv_message(Config),
     #presence{from = JID, to = JID} = recv_presence(Config),
     send(Config, #iq{type = result, id = IQ#iq.id,
 		     to = JID, sub_els = [Info]}),
@@ -1091,7 +1095,7 @@ update_sql(Host, Config) ->
     end.
 
 schema_suffix(Config) ->
-    case ejabberd_sql:use_new_schema() of
+    case ejabberd_sql:use_multihost_schema() of
         true ->
             case ?config(update_sql, Config) of
                 true ->  ".sql";
