@@ -63,7 +63,7 @@ init_config(Config) ->
 		      MacrosContentTpl,
 		      [{c2s_port, 5222},
 		       {loglevel, 4},
-		       {new_schema, false},
+		       {multihost_schema, false},
 		       {update_sql_schema, true},
 		       {s2s_port, 5269},
 		       {stun_port, 3478},
@@ -214,7 +214,7 @@ setup_ejabberd_lib_path(Config) ->
 	    ok
     end.
 
-%% Read environment variable CT_DB=mysql to limit the backends to test.
+%% Read environment variable CT_BACKENDS=mysql to limit the backends to test.
 %% You can thus limit the backend you want to test with:
 %%  CT_BACKENDS=mysql rebar ct suites=ejabberd
 get_config_backends() ->
@@ -229,7 +229,7 @@ get_config_backends() ->
 		  end,
     application:load(ejabberd),
     EnabledBackends = application:get_env(ejabberd, enabled_backends, EnvBackends),
-    misc:intersection(EnvBackends, [mnesia, ldap, extauth|EnabledBackends]).
+    misc:intersection(EnvBackends, [agnostic, mnesia, ldap, extauth|EnabledBackends]).
 
 process_config_tpl(Content, []) ->
     Content;
